# app-store 应用平台

> 支持从 1.0.10 升级到 2.X 版本之上

资源包下载：1.54测试环境`/home/visionread/app-service`

参考工单，侯卫嘉-202407080021 

## yaml 配置

```yaml
version: '3.7'

networks:
  whrp-dossier-net:
    external: true

services:
  app:
    build: ./services/app
    image: app-service:1.0
    container_name: app-service
    restart: always
    volumes:
      - "/data1/dossier/app-service:/data/app"
      - "/data1/dossier/logs/app-service:/logs"
      - "/data1/dossier/tmp/app-service:/tmp"
      - "./services/app/conf:/root/app/conf"
    environment:
      PARAMS: -server -Xmx4g -Xms4g -Dspring.profiles.active=dev -Dspring.config.location=/root/app/conf/application.yml
    healthcheck:
      test: ["CMD", "curl", "-f", "http://localhost:8080"] # 设置检测程序
      interval: 1m30s # 设置检测间隔
      timeout: 10s # 设置检测超时时间
      retries: 3 # 设置重试次数
      start_period: 40s # 启动后，多少秒开始启动检测程序
    networks:
      - whrp-dossier-net

  redis:
    image: redis:6.0
    container_name: app-redis
    restart: always
    entrypoint: docker-entrypoint.sh redis-server /usr/local/etc/redis/redis.conf
    volumes:
      - "./services/redis/redis.conf:/usr/local/etc/redis/redis.conf"
    networks:
      - whrp-dossier-net

  nginx:
    image: whrp.base.nginx:1.24.0
    container_name: app-nginx
    restart: always
    ports:
      - "8555:80"
    volumes:
      - "./services/nginx/nginx.conf:/etc/nginx/nginx.conf"
      - "/data1/dossier/logs/app-nginx:/var/log/nginx"
      - "/data1/dossier/tmp/app-nginx:/tmp"
      - "./services/nginx/webroot:/usr/share/nginx/html"
    logging:
      driver: "json-file"
      options:
        max-size: "100m"
    networks:
      - whrp-dossier-net


```

## application.yaml

修改 `./services/app/conf/application.yaml`

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_1c4f70a32f8dd13e6f3d89e3e69eddd4_r.png)

需要修改的地方：

- `type: com.whrp.framework.core.mybatis.EncHikariDataSource`
	- 数据库密码使用密文，注释掉该行，则填写数据库密码时使用明文填写
- `url`: 更改对应数据库地址
- `username`: 数据库用户名
- `password`: 数据库密码

- `web: domain: `: 当前服务对外地址
- `center: url`: 中心服务器(client-center)地址

## 执行sql

```mysql
ALTER TABLE app_store.`user` MODIFY COLUMN create_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP NULL;
ALTER TABLE app_store.`user` MODIFY COLUMN id bigint auto_increment NOT NULL;
ALTER TABLE app_store.`user` ADD status int DEFAULT 1 NOT NULL COMMENT '状态 1=有效，0=失效';
ALTER TABLE app_store.`user` MODIFY COLUMN password varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT '' NOT NULL;

ALTER TABLE app_store.app MODIFY COLUMN user_id bigint NULL COMMENT '上传人';


CREATE INDEX app_path_IDX USING BTREE ON app_store.app (`path`);
CREATE INDEX app_unique_name_IDX USING BTREE ON app_store.app (unique_name,version_name);

```