# sentinel 流控服务部署

> 官方文档：https://sentinelguard.io/zh-cn/docs/introduction.html

**部署前提前联系研发（崔总），需要配合提供 lisence 文件。**

下载sentinel 相关包：https://work.everydo.com/share?shareid=67e11cdcffcd749f0096544d (访问密码:1234)

## 1、 导入jar包、配置文件

### 1.1 服务器中，导入对应服务：

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_a671afdc165fdab74508329754ac4653_r.png)

### 1.2 nacos中导入流控文件配置

nacos新增两个配置文件，配置格式为json

- sentinel-gateway-api
- sentinel-gateway-flow-rules

导入配置文件：nacos_config_export_20250304144326.zip

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_33f5aa9df64814e2ba5c3c01f1e5a038_r.png)

修改配置文件为json格式

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_db23e064967c637740afcf4c937c9faa_r.png)
![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_c6fff300656891e5ec0fa79240b272e6_r.png)

## 2、docker-compose.yml 配置 sentinel （流控服务）

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_041997e432f499bc4917c83a6984b6df_r.png)

```yaml
  # 流控服务
  sentinel:
    build: ./services/sentinel
    image: whrp.base.sentinel-service:1.8.3
    container_name: sentinel-service
    restart: always
    ports:
      - "8089:8080"
    environment:
      PARAMS: -server -Xmx1g -Xms1g -Dserver.port=8080 -Dsentinel.dashboard.auth.username=sentinel -Dsentinel.dashboard.auth.password=^whrp2017$$ -Dcsp.sentinel.config.file=/root/app/conf/sentinel.properties
    volumes:
      - "./services/sentinel/conf/sentinel.properties:/root/app/conf/sentinel.properties"
      - ${DOSSIER_DATA_DIR}/logs/sentinel:/root/logs/csp/
    networks:
      - whrp-dossier-net

```

- 根据现场实际情况，修改对应端口、账号、密码、文件路径、所属网络


## 3、升级网关

### 3.1、网关信息：

网关版本：1.3.0

下载地址：https://app.nat.whrunpu.com/app/detail?id=1896767325655404544

### 3.2 修改网关 bootstrap.yml

删除多余配置:

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_55c507eb042fda7e0feb021e2cbd92a7_r.png)

### 4.3、修改docker-compose.yml文件中网关端口，新开一个端口：

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_31376fe85bc14cc36b6b4069a7607415_r.png)

### 4.4、nacos中，修改网关gateway.yml配置

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_4bb05b242f61a6b6ffc50fdc573c9594_r.png)

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_d36bfca83cffb2429d941157270d073e_r.png)



对应文本：

```yaml
spring:
  autoconfigure.exclude: >
      com.whrp.framework.core.conf.ConfAutoConfiguration,
      com.whrp.framework.core.mvc.WebMvcConfigurerAdapter,
      com.whrp.framework.core.mvc.SpringMvcAutoConfiguration,
      com.whrp.framework.core.rabbitmq.RabbitmqAutoConfiguration,
      com.whrp.framework.core.security.SpringSecurityActuatorConfig,
      com.whrp.framework.core.serial.SerialNoAutoConfiguration,
      org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration
  servlet:
      multipart:
        # 单个文件的最大值
        max-file-size: 500MB
        # 上传文件总的最大值
        max-request-size: 1024MB


  cloud:
    sentinel:
      eager: true
      scg:
        fallback:
          mode: response
          response-body: '{"code":403,"msg":"请求超过最大数，请稍后再试"}'
      transport:
        client-ip: 131.102.1.54
        dashboard: 131.102.1.54:8089
        port: 8201 
    gateway:
      #white-list: /caseinfo/file/download,/transfer/statistic/**,/transfer/case/search,/basic/config/get,/note/file/**,/user/config,/user/captcha
      white-list: > 
        /caseinfo/file/download*,/user/captcha,/user/send-login-code,/basic/config/get,/note/file/**,/hrms/file/viewer/**,/transfer/file/viewer/**
        ,/transfer/file/upload-certificate,/transfer/file/download,/auth/**
```




### 4.5、获取硬件信息

以上内容成功执行后，第一次构建新的网关服务时，网关服务日志会显示缺失lisence文件，这是因为最新的网关服务,添加了认证机制。当前服务第一次启动后,会在当前部署服务的conf目录下,生成一个hardware文件，此文件记录的是服务启动过程中，获取到的硬件信息参数。此时，需要将该文件回传给研发（联系崔总），研发会根据该 hardware 文件中的信息，生成一个license文件，并回传给现场。现场获取到该文件后,将该文件放入到和hardware文件同一文件夹的同一级下。此时重新启动gateway服务，服务即可成功运行。



网关服务 conf 目录如下：

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_704fd7f588020b01886df32aeb887394_r.png)



## 5、 重启所有前端服务、检查各个服务是否正常

重启 services/views 下所有的前端服务，并检查各个服务是否正常



## 6、查看Sentinel流控服务

浏览器打开地址：http://131.102.1.54:8089/，输入docker-compose.yml中配置的账户密码：

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_9fc7689e6215cab03d2d63cab7341317_r.png)


随便打开一个案件，这里会实时显示流量：

![](https://doc.dev.whrunpu.com/uploads/hebei-wiki/images/m_4616e19ce649a690cf23e6f7dc89b55e_r.png)